@@ -97,7 +97,7 @@ def http_server(port):
   sock.bind((addr, port))
   sock.listen(1)
   ## server loop
-  while http_running is True:
+  while state.http_running is True:
     try:
       if not conn:
         conn, addr = sock.accept()
@@ -154,7 +154,7 @@ def rev_shell(addr, port):
 
 
 def parse_to_dict(data):
-  if data[0] is "{":
+  if data[0] == "{":
     ## try to parse as json encoded data
     try:
       return json.loads(data)
@@ -202,7 +202,7 @@ def cmd_config(cmd):
     if cmd[1] == "save":
       ## make sure our directory exists
       if not os.path.isdir(config_path):
-        os.mkdir(config_path)
+        os.makedirs(config_path)
       ## save our config to json
       with open(name, 'w') as my_config:
         my_config.write(cfg.dump())
@@ -393,16 +393,15 @@ def cmd_history(cmd):
 
 def cmd_http(cmd):
   ## control our local http server
-  global http_running
   if len(cmd) == 1:
-    if http_running is True:
+    if state.http_running is True:
       sys.stdout.write("[*] HTTP server listening on %s\n" % cfg.http_port)
       sys.stdout.write("[*] HTTP payload: %s\n" % cfg.payload_type)
     else:
       sys.stdout.write("[*] HTTP server is not running\n")
     return
   if cmd[1] == "start":
-    if http_running is False:
+    if state.http_running is False:
       if len(cmd) > 2:
         try:
           cfg.http_port = int(cmd[2])
@@ -411,13 +410,13 @@ def cmd_http(cmd):
           return
       s = threading.Thread(target=http_server, args=(cfg.http_port,))
       s.start()
-      http_running = True
+      state.http_running = True
       sys.stdout.write("[*] HTTP server listening on %s\n" % cfg.http_port)
     else:
       sys.stderr.write("[!] HTTP server already running\n")
   elif cmd[1] == "stop":
-    if http_running is True:
-      http_running = False
+    if state.http_running is True:
+      state.http_running = False
       time.sleep(1)
     else:
       sys.stderr.write("[!] HTTP server already stopped\n")
@@ -434,13 +433,17 @@ def cmd_http(cmd):
 
 
 def cmd_marker(cmd):
-  print(cmd)
   ## set the marker for our rce payloads
   ## this will determine boundaries to split and clean output
   if len(cmd) == 1:
     sys.stderr.write("[*] Payload marker: %s\n" % (cfg.marker))
+    if cfg.marker:
+      idx_str = ' '.join(str(idx) for idx in cfg.marker_idx)
+    else:
+      idx_str = 'disabled'
+    sys.stderr.write("[*] Marker indices: %s\n" % (idx_str))
     return
-  ## let's remove ".marker" from our cmd
+  ## let's remove "marker" from our cmd
   cmd.pop(0)
 
   ## assign our action and remove it from cmd
@@ -451,6 +454,7 @@ def cmd_marker(cmd):
   if action == "set":
     ## set the rest of the string as our marker
     cfg.marker = " ".join(cmd)
+    if not cfg.marker: cfg.marker = None
     sys.stdout.write("[*] Payload output marker set.\n")
   elif action == "out":
     cfg.marker_idx = [int(idx) for idx in cmd]
